@@ -1,5 +1,5 @@
 package Ryu::Source;
-$Ryu::Source::VERSION = '0.003';
+$Ryu::Source::VERSION = '0.004';
 use strict;
 use warnings;
 
@@ -939,10 +939,23 @@ sub get {
     })->get
 }
 
-for my $k (qw(then cancel fail on_ready transform is_ready is_done failure is_cancelled else await)) {
+for my $k (qw(then cancel fail on_ready transform is_ready is_done failure is_cancelled else)) {
 	do { no strict 'refs'; *$k = $_ } for sub { shift->completed->$k(@_) }
 }
 
+=head2 await
+
+Block until this source finishes.
+
+=cut
+
+sub await {
+    my ($self) = @_;
+    my $f = $self->completed;
+    $f->await until $f->is_ready;
+    $self
+}
+
 sub finish { shift->completed->done }
 
 sub refresh { }
